@@ -2,5 +2,7 @@
 # -*- coding: utf-8 -*-
 from collections import *
 
-if not 'OrderedDict' in dir():
+
+if 'OrderedDict' not in dir():
+    from _backported import Counter
     from _backported import OrderedDict
