@@ -253,7 +253,7 @@ class HTTPHandler(object):
             path = os.path.sep.join(path)
             if sys.version_info < (3, 0):       # workaround for #327 (cherrypy issue)
                 path = path.decode('utf-8')     # make it work with non-ascii
-            else:
+            elif cherry.needs_serve_file_utf8_fix:
                 path = codecs.decode(codecs.encode(path, 'latin1'), 'utf-8')
             fullpath = os.path.join(cherry.config['media.basedir'], path)
 
@@ -347,7 +347,7 @@ class HTTPHandler(object):
             _save_and_release_session()
             zipmime = 'application/x-zip-compressed'
             cherrypy.response.headers["Content-Type"] = zipmime
-            zipname = 'attachment; filename="music.zip"'
+            zipname = 'attachment; filename="CherryMusic-archive.zip"'
             cherrypy.response.headers['Content-Disposition'] = zipname
             basedir = cherry.config['media.basedir']
             fullpath_filelist = [os.path.join(basedir, f) for f in filelist]
@@ -654,7 +654,9 @@ class HTTPHandler(object):
         return playlists
 
     def api_logout(self):
-        cherrypy.lib.sessions.expire()
+        cherrypy.session['username'] = None
+        cherrypy.session['userid'] = None
+        cherrypy.session['admin'] = None
     api_logout.no_auth = True
 
     def api_downloadpls(self, plid, hostaddr):
