@@ -23,7 +23,10 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>
 #
 
-from collections import MutableMapping
+try:
+    from collections.abc import MutableMapping
+except ImportError:
+    from collections import MutableMapping
 import codecs
 from functools import reduce
 import struct
